This is an automated email from the ASF dual-hosted git repository.
kturner pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/fluo.git
The following commit(s) were added to refs/heads/master by this push:
new 4207df4 fixed #954 Appended FLUO_JAVA_OPTS to JAVA_OPTS in
fluo-env.sh (#966)
4207df4 is described below
commit 4207df4f62069e530b0e45f055c123d16e2136ed
Author: Sri Kailash Gandebathula <[email protected]>
AuthorDate: Sun Nov 5 19:48:11 2017 +0100
fixed #954 Appended FLUO_JAVA_OPTS to JAVA_OPTS in fluo-env.sh (#966)
---
modules/distribution/src/main/config/fluo-env.sh | 6 ++++--
1 file changed, 4 insertions(+), 2 deletions(-)
diff --git a/modules/distribution/src/main/config/fluo-env.sh
b/modules/distribution/src/main/config/fluo-env.sh
index 0b29665..78acbb1 100755
--- a/modules/distribution/src/main/config/fluo-env.sh
+++ b/modules/distribution/src/main/config/fluo-env.sh
@@ -36,8 +36,10 @@ export FLUO_TMP="${FLUO_TMP:-/tmp}"
## Fluo log4j configuration
export FLUO_LOG4J_CONFIG="${FLUO_LOG4J_CONFIG:-${conf}/log4j.properties}"
-## Java options for Fluo command
-JAVA_OPTS=("-Dlog4j.configuration=file:${FLUO_LOG4J_CONFIG}")
+## Java options along with FLUO_JAVA_OPTS for Fluo command
+JAVA_OPTS=("${FLUO_JAVA_OPTS[@]}"
"-Dlog4j.configuration=file:${FLUO_LOG4J_CONFIG}")
+
+
export JAVA_OPTS
##########################
--
To stop receiving notification emails like this one, please contact
['"[email protected]" <[email protected]>'].